Changelog
=========

1.2.2 (2021-04-20)
------------------

- Do not translate the no value token to avoid an error when translated.
  [mpeeters]

- Added needed ajax parameter for corresponding collective.js.chosen
  [cedricmessiant, sgeulette]

1.2.1 (2014-09-25)
------------------

- Widget works when the field is initially hidden (for instance in an overlay).
  [thomasdesvenain]

- Pyflakes, pep8, unused code removed, etc.
  [thomasdesvenain]


1.2 (2014-06-03)
----------------

- Set width, and apply as chosen parameter rather than styling widgets with a
  specific width; doing so ensures chosen will set a valid width when it's
  initialized off-screen or when the element applied to it is invisible.
  [damilgra]

- Updated french translations.
  [cedricmessiant]


1.1 (2013-06-04)
----------------

- buildout, tests & travis [kiorky]

- Change prompt message and update French translations.
  Fix bug for no value in List fields.
  [cedricmessiant]


1.0 (2012-06-06)
----------------

* Initial release [kiorky]
